@@ -2,7 +2,7 @@ package Device::Firmata::IO::NetIO;
 
 =head1 Name
 
-Device::Firmata::IO::NetIO - implements the low level TCP/IP server socket IO.
+Device::Firmata::IO::NetIO - TCP/IP server interface to Firmata device
 
 =cut
 
@@ -253,7 +253,7 @@ sub close {
 
 =head1 SEE ALSO
 
-L<Device::Firmata::Base>
+L<Device::Firmata::listen ( host, port, [opts] )> and L<Device::Firmata::Platform::attach ( ioPort )>
 
 =cut
 
